#-*- Makefile -*-
require DE_EPAGES::Core::API::Makefile;
chmod 0644, "makefile";
__DATA__

STORES = Site $(EPAGES_SHOP_STORES)
SLANG		= it
DIALECT		= 
VERSION		= 6.17.20
TO_NULL		= >$(NUL) 2>&1

IMPORT_PL	= $(PERL) "$(EPAGES_CARTRIDGES)/DE_EPAGES/Object/Scripts/import.pl"
DELETE_PL	= $(PERL) "$(EPAGES_CARTRIDGES)/DE_EPAGES/Object/Scripts/delete.pl"
INSTALL_LANGPACK   = $(PERL) "$(EPAGES_CARTRIDGES)/DE_EPAGES/Installer/Scripts/installLanguagePack.pl"
UNINSTALL_LANGPACK = $(PERL) "$(EPAGES_CARTRIDGES)/DE_EPAGES/Installer/Scripts/uninstallLanguagePack.pl"
REGISTER_CARTRIDGES = $(PERL) "$(EPAGES_CARTRIDGES)/DE_EPAGES/ShopConfiguration/Scripts/registercartridges.pl"

!OS_SPECIFIC_DEFINES
!ifndef WINDOWS
WHOAMI		= $(shell whoami)
EPWEB		= $(shell echo $(EPAGES_WEBGROUP) | $(AWK) -F: '{print $$1}')
SU_EXE		= $(shell runuser -c true 2>/dev/null && echo runuser || echo su)
EPAGES_PROJECT	?= epages6
EPAGES_DEFAULT 	= /etc/default/$(EPAGES_PROJECT)
EPAGES_APPUSER	?= eprunapp
CPrp		= /bin/cp -rp --remove-destination
!endif

var\EPAGES_WEBGROUP var\EPAGES_LOG var\EPAGES_CONFIG var\EPAGES_WEBROOT var\EPAGES_STORES var\EPAGES_STATIC var\EPAGES_PERL var\EPAGES_CARTRIDGES:
!ifndef WINDOWS
	@[ -n "$($(@F))" ] ||\
 { echo "ePages environment not set correctly, please execute: . $(EPAGES_DEFAULT)" ; exit 127; }
	@[ "$(WHOAMI)" = "root" ] ||\
 { echo "Please run '$(MAKE)' as user 'root', not as '$(WHOAMI)'."; exit 127; }
!endif

$(STORES)::

install: copy_files all\activate_db all\install_db
!ifndef EPAGES_IGNORE_SITE
	$(REGISTER_CARTRIDGES)
!endif

uninstall: del_files all\deactivate_db all\uninstall_db

all\install_db all\activate_db all\deactivate_db all\uninstall_db: $(STORES)
!ifdef WINDOWS
	!$(MAKE) $(@F) STORE=$**
!else
	for i in $^ ; do $(MAKE) $(@F) STORE=$$i ; done
!endif

install_db: var\EPAGES_PERL var\EPAGES_CARTRIDGES
!ifndef STORE
	@echo "$(MAKE) variable STORE empty, exiting." && exit 127
!endif
	$(INSTALL_LANGPACK) -storename $(STORE) -lang $(SLANG) -dialect "$(DIALECT)"

uninstall_db: var\EPAGES_PERL var\EPAGES_CARTRIDGES
!ifndef STORE
	@echo "$(MAKE) variable STORE empty, exiting." && exit 127
!endif
	$(UNINSTALL_LANGPACK) -storename $(STORE) -lang $(SLANG) -dialect "$(DIALECT)"

activate_db: var\EPAGES_PERL var\EPAGES_CARTRIDGES
!ifndef STORE
	@echo "$(MAKE) variable STORE empty, exiting." && exit 127
!endif
	$(IMPORT_PL) -storename $(STORE) Languages_install.xml
	$(IMPORT_PL) -storename $(STORE) Locales_install.xml
	$(IMPORT_PL) -storename $(STORE) System.xml

deactivate_db: var\EPAGES_PERL var\EPAGES_CARTRIDGES
!ifndef STORE
	@echo "$(MAKE) variable STORE empty, exiting." && exit 127
!endif
	$(IMPORT_PL) -storename $(STORE) Locales_uninstall.xml
	$(IMPORT_PL) -storename $(STORE) Languages_uninstall.xml
	$(DELETE_PL) -storename $(STORE) System.xml

copy_files: var\EPAGES_WEBROOT var\EPAGES_CARTRIDGES
!ifndef WINDOWS
	$(COPY_DIR) Cartridges "$(EPAGES_CARTRIDGES)"
!else
	/etc/init.d/$(EPAGES_PROJECT) perm all -d .
	$(CPrp) Cartridges/* "$(EPAGES_CARTRIDGES)"
!endif
	$(PERL) $(EPAGES_CARTRIDGES)/DE_EPAGES/JQuery/Scripts/DictionaryConverter.pl -cartridge ALL -storename "$(STORES)" -version $(VERSION)
	$(PERL) $(EPAGES_CARTRIDGES)/DE_EPAGES/Presentation/Scripts/buildUi.pl -store "$(STORES)" -version $(VERSION) -filter "**/*.$(SLANG).json"

del_files:
	$(UNINSTALL_LANGPACK) -lang $(SLANG) -del_files -dialect "$(DIALECT)"
